#[non_exhaustive]pub enum Request<'a> {
Destroy,
Lock {},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Destroy
destroy the session lock manager object
This informs the compositor that the session lock manager object will no longer be used. Existing objects created through this interface remain valid.
This is a destructor, once sent this object cannot be used any longer.
Lock
attempt to lock the session
This request creates a session lock and asks the compositor to lock the session. The compositor will send either the ext_session_lock_v1.locked or ext_session_lock_v1.finished event on the created object in response to this request.
Implementations